@@ -1,24 +1,25 @@
 import functools
+import logging
 from typing import Awaitable, Callable, Type
 
 from fastapi import FastAPI
 from fastapi.middleware.gzip import GZipMiddleware
 from starlette.middleware.cors import CORSMiddleware
 
-from .config import DatabaseType, Settings, StorageType, get_settings, AuthType
+from .config import AuthType, DatabaseType, Settings, StorageType, get_settings
 from .exception_handlers import setup_exception_handlers
 from .exceptions import (
+    AlreadyExistsError,
     BadRequestError,
     DatabaseError,
     ForbiddenError,
     HTTPException,
-    NotFoundError,
     InternalServerError,
+    NotFoundError,
     NotImplementedError,
     StorageError,
     UnauthorizedError,
     UnknownError,
-    AlreadyExistsError
 )
 from .models import CamelModel, FileDownloadRef
 from .responses import UJSONResponse
@@ -38,7 +39,7 @@ from .utils import (
 
 __author__ = "Samuel Bradley"
 __email__ = "sam.bradley@csiro.au"
-__version__ = "1.2.0"
+__version__ = "1.3.2"
 
 
 def create_app(
@@ -46,20 +47,22 @@ def create_app(
     disable_gzip: bool = False,
     on_start: Callable[[FastAPI], Awaitable[None]] = None,
     on_stop: Callable[[FastAPI], Awaitable[None]] = None,
-    **kwargs
+    **kwargs,
 ) -> FastAPI:
     settings = get_settings(env_path)
 
-    if settings.SENTRY_DSN is not None:
-        import sentry_sdk
+    if settings.ROLLBAR_KEY is not None:
+        import rollbar
+        from rollbar.contrib.fastapi import add_to as rollbar_add_to
 
-        sentry_sdk.init(settings.SENTRY_DSN)
+        rollbar.init(
+            settings.ROLLBAR_KEY, environment=settings.ENVIRONMENT, handler="async", include_request_body=True
+        )
 
-    app = FastAPI(
-        title=settings.PROJECT_NAME,
-        openapi_url=f"{settings.API_PRE_PATH}/openapi.json",
-        **kwargs
-    )
+    app = FastAPI(title=settings.PROJECT_NAME, openapi_url=f"{settings.API_PRE_PATH}/openapi.json", **kwargs)
+
+    if settings.ROLLBAR_KEY is not None:
+        rollbar_add_to(app)
 
     # CORS
     origins = []
@@ -85,7 +88,7 @@ def create_app(
         app.add_middleware(GZipMiddleware, minimum_size=5000)
 
     if settings.SECURE:
-        from secure import SecureHeaders, SecureCookie
+        from secure import SecureCookie, SecureHeaders
 
         secure_headers = SecureHeaders()
 
@@ -112,8 +115,8 @@ def create_app(
 
 
 async def start_app(app: FastAPI):
+    from fa_common.db import create_indexes, setup_db
     from fa_common.storage import setup_storage
-    from fa_common.db import setup_db, create_indexes
 
     if get_settings().USE_FIREBASE:
         import firebase_admin
