@@ -7,13 +7,13 @@ from jose import JWTError, jwt
 from pydantic import ValidationError
 
 from fa_common import (
+    AuthType,
     ForbiddenError,
-    UnauthorizedError,
     InternalServerError,
+    UnauthorizedError,
     async_get,
     force_async,
     get_settings,
-    AuthType,
 )
 from fa_common import logger as LOG
 
@@ -151,6 +151,7 @@ async def get_user(payload: dict, token: str, get_profile: bool = True) -> Optio
 
     return user
 
+
 async def get_standalone_user() -> AuthUser:
     """
     Manage user authentication and identity management using a
@@ -176,9 +177,8 @@ async def get_standalone_user() -> AuthUser:
             detail="Standalone authentication not enabled",
         )
 
-    return AuthUser(sub="standalone",
-                    name="Default User",
-                    scopes=["read:me"])
+    return AuthUser(sub="standalone", name="Default User", scopes=["read:me"])
+
 
 async def get_current_user(
     security_scopes: SecurityScopes,
@@ -211,6 +211,6 @@ async def get_current_user(
                 )
     return user
 
+
 async def get_auth_simple(security_scopes: SecurityScopes, token: str = Depends(oauth2_scheme)) -> AuthUser:
     return await get_current_user(security_scopes, token, False)
-
