@@ -4,7 +4,7 @@ from enum import Enum
 from typing import List, Optional, Set
 
 from dotenv import load_dotenv
-from pydantic import AnyUrl, BaseSettings, SecretBytes, SecretStr
+from pydantic import BaseSettings, SecretBytes, SecretStr
 
 # from app.shared.utils import auth
 
@@ -28,14 +28,15 @@ class AuthType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "1.2.0"
+    VERSION: str = "1.3.2"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
     SECURE = False  # Use secure.py (set to true for prod)
-    SENTRY_DSN: Optional[AnyUrl] = None
+    ROLLBAR_KEY: Optional[str] = None
     DEBUG: bool = False
     UNIT_TESTING: bool = False
+    ENVIRONMENT: str = "local"
 
     SECRET_KEY: SecretBytes = os.urandom(32)  # type:ignore
     BUILD_DATE: Optional[str] = None
