@@ -1,8 +1,9 @@
 import typing
 
-import ujson
 import orjson
-from starlette.responses import JSONResponse, UJSONResponse as BaseUJSONResponse
+import ujson
+from starlette.responses import JSONResponse
+from starlette.responses import UJSONResponse as BaseUJSONResponse
 
 
 class UJSONResponse(BaseUJSONResponse):
