@@ -1,22 +1,18 @@
+import json
 import time
 from collections.abc import Iterable
-
-from gitlab import Gitlab
-from gitlab.v4.objects import Project, ProjectPipeline, ProjectJob
-from gitlab.exceptions import (
-    GitlabGetError,
-    GitlabCreateError,
-    GitlabDeleteError,
-    GitlabJobRetryError,
-)
+from typing import Dict, List, Optional, Union
 
 import yaml
-import json
-from typing import List, Union, Dict, Optional
+from gitlab import Gitlab
+from gitlab.exceptions import GitlabCreateError, GitlabDeleteError, GitlabGetError, GitlabJobRetryError
+from gitlab.v4.objects import Project, ProjectJob, ProjectPipeline
+
 from fa_common import force_async, get_current_app, get_settings
 from fa_common import logger as LOG
+
+from .models import JobAction, JobRun, WorkflowRun
 from .utils import GitlabCIYAMLDumper
-from .models import WorkflowRun, JobRun, JobAction
 
 
 class GitlabClient:
@@ -29,7 +25,7 @@ class GitlabClient:
     """
 
     __instance = None
-    gitlab: Gitlab = None
+    gitlab: Gitlab
 
     def __new__(cls) -> "GitlabClient":
         if cls.__instance is None:
@@ -57,9 +53,7 @@ class GitlabClient:
 
     async def _get_project_by_name(self, project_name: str):
         settings = get_settings()
-        projects = await force_async(self.gitlab.projects.list)(
-            search=project_name, owned=True
-        )
+        projects = await force_async(self.gitlab.projects.list)(search=project_name, owned=True)
         for proj in projects:
             group_id = proj.namespace["id"]
             if proj.name == project_name and group_id == settings.GITLAB_GROUP_ID:
@@ -89,9 +83,7 @@ class GitlabClient:
         data = {
             "branch": "master",
             "commit_message": "First Commit",
-            "actions": [
-                {"action": "create", "file_path": ".gitlab-ci.yml", "content": ""}
-            ],
+            "actions": [{"action": "create", "file_path": ".gitlab-ci.yml", "content": ""}],
         }
         commit = await force_async(project.commits.create)(data)
         LOG.info(f"Created CI Commit: {commit.id}")
@@ -101,9 +93,7 @@ class GitlabClient:
 
     async def create_branch(self, project_id: int, branch_name: str):
         project = await self._get_project(project_id)
-        branch = await force_async(project.branches.create)(
-            {"branch": branch_name, "ref": "master"}
-        )
+        branch = await force_async(project.branches.create)({"branch": branch_name, "ref": "master"})
         LOG.info(f"Created branch: {branch}")
         return branch
 
@@ -114,9 +104,7 @@ class GitlabClient:
             LOG.info(f"Deleted branch: {branch_name}")
         except GitlabDeleteError as err:
             if str(err.response_code) == "404":
-                raise ValueError(
-                    f"Trying to delete branch {branch_name} that doesn't exist."
-                )
+                raise ValueError(f"Trying to delete branch {branch_name} that doesn't exist.")
             raise err
 
     async def get_job(
@@ -133,9 +121,7 @@ class GitlabClient:
             if include_log:
                 log = job.trace()
         except GitlabGetError:
-            raise ValueError(
-                f"No job found with the id {job_id} in project {project_id}"
-            )
+            raise ValueError(f"No job found with the id {job_id} in project {project_id}")
 
         return self.job_to_job_run(job, log, include_output)
 
@@ -159,9 +145,7 @@ class GitlabClient:
                 {
                     "action": "update",
                     "file_path": ".gitlab-ci.yml",
-                    "content": yaml.dump(
-                        ci_file, Dumper=GitlabCIYAMLDumper, default_flow_style=False
-                    ),
+                    "content": yaml.dump(ci_file, Dumper=GitlabCIYAMLDumper, default_flow_style=False),
                 }
             ],
         }
@@ -183,23 +167,20 @@ class GitlabClient:
         pipeline = project.pipelines.create({"ref": branch, "variables": variables})
         if wait:
             while pipeline.finished_at is None:
-                LOG.info(
-                    f"Waiting for workflow {pipeline.id} to finish, sleeping for 5 seconds"
-                )
+                LOG.info(f"Waiting for workflow {pipeline.id} to finish, sleeping for 5 seconds")
                 time.sleep(5)
                 pipeline.refresh()
 
         return await self.pipeline_to_workflow_run(pipeline, project, include_output)
 
     def job_to_job_run(
-        self, job: ProjectJob, job_log: bytes = None, include_output: bool = True,
+        self,
+        job: ProjectJob,
+        job_log: bytes = None,
+        include_output: bool = True,
     ) -> JobRun:
         output = None
-        if (
-            include_output
-            and hasattr(job, "artifacts_file")
-            and job.artifacts_file is not None
-        ):
+        if include_output and hasattr(job, "artifacts_file") and job.artifacts_file is not None:
             try:
                 output_bytes = None
                 output_bytes = job.artifact(f"output/{job.id}/outputs.json")
@@ -228,7 +209,10 @@ class GitlabClient:
         return job_run
 
     async def pipeline_to_workflow_run(
-        self, pipeline: ProjectPipeline, project: Project, include_output: bool = False,
+        self,
+        pipeline: ProjectPipeline,
+        project: Project,
+        include_output: bool = False,
     ) -> WorkflowRun:
         hidden_jobs: List[JobRun] = []
         jobs = await force_async(pipeline.jobs.list)()
@@ -237,10 +221,7 @@ class GitlabClient:
             project_job = project.jobs.get(job.id)
             job_run = self.job_to_job_run(project_job, include_output=include_output)
             if job_dict.get(job_run.name) is not None:
-                if (
-                    job_dict[job_run.name].get_compare_time()
-                    < job_run.get_compare_time()
-                ):
+                if job_dict[job_run.name].get_compare_time() < job_run.get_compare_time():
                     hidden_jobs.append(job_dict[job_run.name])
                     job_dict[job_run.name] = job_run
                 else:
@@ -276,9 +257,7 @@ class GitlabClient:
 
     async def delete_project_by_name(self, project_name: str, wait: bool = True):
         settings = get_settings()
-        projects = await force_async(self.gitlab.projects.list)(
-            search=project_name, owned=True
-        )
+        projects = await force_async(self.gitlab.projects.list)(search=project_name, owned=True)
         LOG.info(f"Found projects: {projects}")
         for proj in projects:
             group_id = proj.namespace["id"]
@@ -304,11 +283,7 @@ class GitlabClient:
                 pipeline = await force_async(project.pipelines.get)(job.pipeline["id"])
                 jobs = await force_async(pipeline.jobs.list)()
                 for _job in jobs:
-                    if (
-                        _job.name == job.name
-                        and _job.status in ["pending", "running"]
-                        and _job.id != job.id
-                    ):
+                    if _job.name == job.name and _job.status in ["pending", "running"] and _job.id != job.id:
                         job = _job
                         break
 
@@ -318,9 +293,7 @@ class GitlabClient:
             job = await force_async(project.jobs.get)(job.id)
             return self.job_to_job_run(job, include_output=False)
         except GitlabGetError:
-            raise ValueError(
-                f"No job found with the id {job_id} in project {project_id}"
-            )
+            raise ValueError(f"No job found with the id {job_id} in project {project_id}")
         except GitlabJobRetryError:
             raise ValueError(f"Job {job_id} is not currently retryable.")
 
@@ -330,26 +303,18 @@ class GitlabClient:
         project = await self._get_project(project_id)
         try:
             pipeline = await force_async(project.pipelines.get)(pipeline_id)
-            return await self.pipeline_to_workflow_run(
-                pipeline, project, include_output
-            )
+            return await self.pipeline_to_workflow_run(pipeline, project, include_output)
         except GitlabGetError:
-            raise ValueError(
-                f"No pipeleine found with the id {pipeline_id} in project {project_id}"
-            )
+            raise ValueError(f"No pipeleine found with the id {pipeline_id} in project {project_id}")
 
-    async def retry_pipeline(
-        self, project_id: Union[str, int], pipeline_id: int
-    ) -> WorkflowRun:
+    async def retry_pipeline(self, project_id: Union[str, int], pipeline_id: int) -> WorkflowRun:
         project = await self._get_project(project_id)
         try:
             pipeline = await force_async(project.pipelines.get)(pipeline_id)
             await force_async(pipeline.retry)()
             return await self.pipeline_to_workflow_run(pipeline, project, False)
         except GitlabGetError:
-            raise ValueError(
-                f"No pipeleine found with the id {pipeline_id} in project {project_id}"
-            )
+            raise ValueError(f"No pipeleine found with the id {pipeline_id} in project {project_id}")
 
     async def delete_pipeline(self, project_id: Union[str, int], pipeline_id: int):
         project = await self._get_project(project_id)
@@ -359,6 +324,4 @@ class GitlabClient:
                 await force_async(pipeline.cancel)()
             await force_async(pipeline.delete)()
         except GitlabGetError:
-            raise ValueError(
-                f"No pipeline found with the id {pipeline_id} in project {project_id}"
-            )
+            raise ValueError(f"No pipeline found with the id {pipeline_id} in project {project_id}")
