@@ -1,14 +1,18 @@
-import os
-import json
-from datetime import datetime
-from typing import List, Union, Optional
-from .models import ScidraModule, JobRun, WorkflowProject, WorkflowRun, JobAction
-from .utils import get_workflow_client
-from fa_common import logger as LOG, get_settings
-from fa_common.storage import File, get_storage_client
-import oyaml as yaml
 import copy
+import json
+import os
+from datetime import datetime
 from io import BytesIO
+from typing import List, Optional, Union
+
+import oyaml as yaml
+
+from fa_common import get_settings
+from fa_common import logger as LOG
+from fa_common.storage import File, get_storage_client
+
+from .models import JobAction, JobRun, ScidraModule, WorkflowProject, WorkflowRun
+from .utils import get_workflow_client
 
 dirname = os.path.dirname(__file__)
 
